/**
 */
package de.mdelab.mlsdm;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import de.mdelab.mlexpressions.MLExpression;
import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Activity Edge</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * Superclass of all edges that can be contained in an Activity. Edges can have a guard. However, depending on the source node only certain kinds of guards are valid. For the guard BOOLEAN, a guardExpression has to be provided.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getSource <em>Source</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getTarget <em>Target</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getActivityNodeContainer <em>Activity Node Container</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getGuardType <em>Guard Type</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getGuardExpression <em>Guard Expression</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getAcquireEdges <em>Acquire Edges</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getReleaseEdges <em>Release Edges</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.ActivityEdge#getAssertionExpressions <em>Assertion Expressions</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge()
 * @model annotation="http://www.eclipse.org/emf/2002/Ecore constraints='ActivityEdgeEndGuard'"
 * @generated
 */
public interface ActivityEdge extends MLElementWithUUID, MLAnnotatedElement {
	/**
	 * Returns the value of the '<em><b>Source</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ActivityNode#getOutgoingEdges <em>Outgoing Edges</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Source</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Source</em>' reference.
	 * @see #setSource(ActivityNode)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_Source()
	 * @see de.mdelab.mlsdm.ActivityNode#getOutgoingEdges
	 * @model opposite="outgoingEdges" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!source'"
	 * @generated
	 */
	ActivityNode getSource();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getSource
	 * <em>Source</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Source</em>' reference.
	 * @see #getSource()
	 * @generated
	 */
	void setSource(ActivityNode value);

	/**
	 * Returns the value of the '<em><b>Target</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ActivityNode#getIncomingEdges <em>Incoming Edges</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Target</em>' reference isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Target</em>' reference.
	 * @see #setTarget(ActivityNode)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_Target()
	 * @see de.mdelab.mlsdm.ActivityNode#getIncomingEdges
	 * @model opposite="incomingEdges" resolveProxies="false" required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!target'"
	 * @generated
	 */
	ActivityNode getTarget();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getTarget
	 * <em>Target</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Target</em>' reference.
	 * @see #getTarget()
	 * @generated
	 */
	void setTarget(ActivityNode value);

	/**
	 * Returns the value of the '<em><b>Activity Node Container</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ActivityNodeContainer#getEdges <em>Edges</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Activity Node Container</em>' container
	 * reference isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Activity Node Container</em>' container reference.
	 * @see #setActivityNodeContainer(ActivityNodeContainer)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_ActivityNodeContainer()
	 * @see de.mdelab.mlsdm.ActivityNodeContainer#getEdges
	 * @model opposite="edges" resolveProxies="false" required="true" transient="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!activityNodeContainer'"
	 * @generated
	 */
	ActivityNodeContainer getActivityNodeContainer();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlsdm.ActivityEdge#getActivityNodeContainer
	 * <em>Activity Node Container</em>}' container reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Activity Node Container</em>'
	 *            container reference.
	 * @see #getActivityNodeContainer()
	 * @generated
	 */
	void setActivityNodeContainer(ActivityNodeContainer value);

	/**
	 * Returns the value of the '<em><b>Guard Type</b></em>' attribute.
	 * The literals are from the enumeration {@link de.mdelab.mlsdm.ActivityEdgeGuardEnum}.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Guard Type</em>' attribute isn't clear, there
	 * really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Guard Type</em>' attribute.
	 * @see de.mdelab.mlsdm.ActivityEdgeGuardEnum
	 * @see #setGuardType(ActivityEdgeGuardEnum)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_GuardType()
	 * @model required="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!guardType'"
	 * @generated
	 */
	ActivityEdgeGuardEnum getGuardType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getGuardType <em>Guard Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Guard Type</em>' attribute.
	 * @see de.mdelab.mlsdm.ActivityEdgeGuardEnum
	 * @see #getGuardType()
	 * @generated
	 */
	void setGuardType(ActivityEdgeGuardEnum value);

	/**
	 * Returns the value of the '<em><b>Guard Expression</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Guard Expression</em>' containment reference
	 * isn't clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Guard Expression</em>' containment reference.
	 * @see #setGuardExpression(MLExpression)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_GuardExpression()
	 * @model containment="true"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!guardExpression'"
	 * @generated
	 */
	MLExpression getGuardExpression();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.ActivityEdge#getGuardExpression <em>Guard Expression</em>}' containment reference.
	 * <!-- begin-user-doc
	 * --> <!-- end-user-doc -->
	 * @param value the new value of the '<em>Guard Expression</em>' containment reference.
	 * @see #getGuardExpression()
	 * @generated
	 */
	void setGuardExpression(MLExpression value);

	/**
	 * Returns the value of the '<em><b>Acquire Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.AcquireEdge}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.AcquireEdge#getActivityEdge <em>Activity Edge</em>}'.
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * Before this edge can be traversed, tokens have to be acquired from the semaphores connected by AcquireEdges.
	 * <!-- end-model-doc -->
	 * @return the value of the '<em>Acquire Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_AcquireEdges()
	 * @see de.mdelab.mlsdm.AcquireEdge#getActivityEdge
	 * @model opposite="activityEdge" resolveProxies="false" ordered="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!acquireEdges'"
	 * @generated
	 */
	EList<AcquireEdge> getAcquireEdges();

	/**
	 * Returns the value of the '<em><b>Release Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.ReleaseEdge}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ReleaseEdge#getActivityEdge <em>Activity Edge</em>}'.
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * When this edge is traversed, tokens are released to the semaphores connected by ReleaseEdges.
	 * <!-- end-model-doc -->
	 * @return the value of the '<em>Release Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_ReleaseEdges()
	 * @see de.mdelab.mlsdm.ReleaseEdge#getActivityEdge
	 * @model opposite="activityEdge" resolveProxies="false" ordered="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!ActivityEdge!releaseEdges'"
	 * @generated
	 */
	EList<ReleaseEdge> getReleaseEdges();

	/**
	 * Returns the value of the '<em><b>Assertion Expressions</b></em>'
	 * containment reference list. The list contents are of type
	 * {@link de.mdelab.mlexpressions.MLExpression}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> A set of assertion
	 * expressions that are evaluated when the edge is traversed (and the
	 * interpreter is configured to evaluate assertions). If an expression is
	 * evaluated to false, an exception is thrown. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Assertion Expressions</em>' containment
	 *         reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getActivityEdge_AssertionExpressions()
	 * @model containment="true" ordered="false"
	 * @generated
	 */
	EList<MLExpression> getAssertionExpressions();

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeBooleanGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeBooleanGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::BOOLEAN and\n *             self.source.oclIsKindOf(DecisionMergeNode) implies\n *             self.source.oclIsTypeOf(DecisionMergeNode)\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The BOOLEAN guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a decision/merge node.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeBooleanGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeBooleanGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_BOOLEAN;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_DecisionMergeNode = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_DecisionMergeNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_DecisionMergeNode).booleanValue();\n\t\tand = oclIsKindOf;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_DecisionMergeNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_DecisionMergeNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source_0 = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsTypeOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsTypeOfOperation%&gt;.INSTANCE.evaluate(executor, source_0, TYP_mlsdm_c_c_DecisionMergeNode_0).booleanValue();\n\t\timplies = oclIsTypeOf;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_BOOLEAN_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_decision_s_merge_32_node);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeBooleanGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeBooleanGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeSuccessGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeSuccessGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::SUCCESS and\n *             self.source.oclIsKindOf(StoryNode) implies\n *             self.source.oclAsType(StoryNode).semantics = StoryNodeSemanticsEnum::SINGLE_MATCH\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The SUCCESS guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a story node with SINGLE_MATCH semantics.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeSuccessGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeSuccessGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_SUCCESS;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_StoryNode_0).booleanValue();\n\t\tand = oclIsKindOf;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@Thrown\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_1 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source_0 = this.getSource();\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNode%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlsdm.StoryNode%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, source_0, TYP_mlsdm_c_c_StoryNode_1));\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNodeSemanticsEnum%&gt; semantics = oclAsType.getSemantics();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_semantics = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_StoryNodeSemanticsEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(semantics.getName()));\n\t\tfinal /*@Thrown\052/ boolean eq_0 = BOXED_semantics == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_SINGLE_MATCH;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_SUCCESS_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_story_32_node_32_with_32_SINGLE_);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeSuccessGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeSuccessGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeGuardType:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeGuardType\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Guard type of activity edge \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeGuardType\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeGuardType);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeGuardType, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean ActivityEdgeGuardType(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeForEachGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeForEachGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::FOR_EACH and\n *             self.source.oclIsKindOf(StoryNode) implies\n *             self.source.oclAsType(StoryNode).semantics = StoryNodeSemanticsEnum::FOR_EACH_FRESH_MATCH\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The FOR_EACH guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a story node with FOR_EACH semantics.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeForEachGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeForEachGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_FOR_EACH;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_StoryNode).booleanValue();\n\t\tand = oclIsKindOf;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@Thrown\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source_0 = this.getSource();\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNode%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlsdm.StoryNode%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, source_0, TYP_mlsdm_c_c_StoryNode_0));\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNodeSemanticsEnum%&gt; semantics = oclAsType.getSemantics();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_semantics = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_StoryNodeSemanticsEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(semantics.getName()));\n\t\tfinal /*@Thrown\052/ boolean eq_0 = BOXED_semantics == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_FOR_EACH_FRESH_MATCH;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_FOR_EACH_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_story_32_node_32_with_32_FOR_EAC);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeForEachGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeForEachGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeSource:\n *   let severity : Integer[1] = \'ActivityEdge::ActivityEdgeSource\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Source of activity edge \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeSource\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeSource);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeSource, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean ActivityEdgeSource(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeElseGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeElseGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::ELSE implies\n *             self.source.oclIsTypeOf(DecisionMergeNode)\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The ELSE guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a decision/merge node.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeElseGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeElseGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_ELSE;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_DecisionMergeNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_DecisionMergeNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsTypeOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsTypeOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_DecisionMergeNode_0).booleanValue();\n\t\timplies = oclIsTypeOf;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_ELSE_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_decision_s_merge_32_node);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeElseGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeElseGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeTarget:\n *   let severity : Integer[1] = \'ActivityEdge::ActivityEdgeTarget\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.target &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Target of activity edge \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeTarget\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeTarget);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeTarget, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean ActivityEdgeTarget(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeFailureGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeFailureGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::FAILURE and\n *             self.source.oclIsKindOf(StoryNode) implies\n *             self.source.oclAsType(StoryNode).semantics = StoryNodeSemanticsEnum::SINGLE_MATCH\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The FAILURE guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a story node with SINGLE_MATCH semantics.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeFailureGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeFailureGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_FAILURE;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_StoryNode_0).booleanValue();\n\t\tand = oclIsKindOf;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@Thrown\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_1 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source_0 = this.getSource();\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNode%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlsdm.StoryNode%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, source_0, TYP_mlsdm_c_c_StoryNode_1));\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNodeSemanticsEnum%&gt; semantics = oclAsType.getSemantics();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_semantics = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_StoryNodeSemanticsEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(semantics.getName()));\n\t\tfinal /*@Thrown\052/ boolean eq_0 = BOXED_semantics == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_SINGLE_MATCH;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_FAILURE_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_story_32_node_32_with_32_SINGLE_);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeFailureGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeFailureGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeGuardExpression:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeGuardExpression\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::BOOLEAN implies self.guardExpression &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'A guard expression for the boolean guard of activity edge \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeGuardExpression\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeGuardExpression);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_BOOLEAN;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlexpressions.MLExpression%&gt; guardExpression = this.getGuardExpression();\n\t\tfinal /*@NonInvalid\052/ boolean ne = guardExpression != null;\n\t\timplies = ne;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_A_32_guard_32_expression_32_for_32_the_32_boolean_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_must_32_be_32_specified);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeGuardExpression, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeGuardExpression(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeNoGuardExpression:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeNoGuardExpression\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardExpression &lt;&gt; null implies self.guardType = ActivityEdgeGuardEnum::BOOLEAN\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'A guard expression may only be specified for boolean guards (activity edge \' +\n *               self.toString() + \').\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeNoGuardExpression\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeNoGuardExpression);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlexpressions.MLExpression%&gt; guardExpression = this.getGuardExpression();\n\tfinal /*@NonInvalid\052/ boolean ne = guardExpression != null;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_BOOLEAN;\n\t\timplies = eq;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_A_32_guard_32_expression_32_may_32_only_32_be_32_specified_32_for_32_boolean_32_guards_32_o_act, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__e_);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeNoGuardExpression, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeNoGuardExpression(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv ActivityEdgeEndGuard:\n *   let\n *     severity : Integer[1] = \'ActivityEdge::ActivityEdgeEndGuard\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.guardType = ActivityEdgeGuardEnum::END and\n *             self.source.oclIsKindOf(StoryNode) implies\n *             self.source.oclAsType(StoryNode).semantics = StoryNodeSemanticsEnum::FOR_EACH_FRESH_MATCH\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The END guard of activity edge \' +\n *               self.toString() + \' is only valid for edges starting from a story node with FOR_EACH semantics.\', status = status\n *             }\n *           endif\n *       in\n *         \'ActivityEdge::ActivityEdgeEndGuard\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeEndGuard);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityEdgeGuardEnum%&gt; guardType = this.getGuardType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_guardType = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_ActivityEdgeGuardEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(guardType.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_guardType == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_END;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_0 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source = this.getSource();\n\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, source, TYP_mlsdm_c_c_StoryNode_0).booleanValue();\n\t\tand = oclIsKindOf;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@Thrown\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlsdm_c_c_StoryNode_1 = idResolver.getClass(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.CLSSid_StoryNode, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlsdm.ActivityNode%&gt; source_0 = this.getSource();\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNode%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlsdm.StoryNode%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, source_0, TYP_mlsdm_c_c_StoryNode_1));\n\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlsdm.StoryNodeSemanticsEnum%&gt; semantics = oclAsType.getSemantics();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_semantics = &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ENUMid_StoryNodeSemanticsEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(semantics.getName()));\n\t\tfinal /*@Thrown\052/ boolean eq_0 = BOXED_semantics == &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.ELITid_FOR_EACH_FRESH_MATCH;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_The_32_END_32_guard_32_of_32_activity_32_edge_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_is_32_only_32_valid_32_for_32_edges_32_starting_32_from_32_a_32_story_32_node_32_with_32_FOR_EAC);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_ActivityEdge_c_c_ActivityEdgeEndGuard, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean ActivityEdgeEndGuard(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // ActivityEdge
