package de.mdelab.mlsdm.diagram.custom.edit.parts;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.EMFEditPlugin;
import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.gmf.runtime.notation.View;

import de.mdelab.mlcallactions.CallAction;
import de.mdelab.mlcallactions.CallActionExpression;
import de.mdelab.mlcallactions.CallActionParameter;
import de.mdelab.mlexpressions.MLExpression;
import de.mdelab.mlsdm.diagram.edit.parts.CallActionExpressionEditPart;

public class CustomCallActionExpressionEditPart extends CallActionExpressionEditPart
{

	public CustomCallActionExpressionEditPart(View view)
	{
		super(view);
	}

	@Override
	protected void addNotationalListeners()
	{
		super.addNotationalListeners();
		CallActionExpression cae = (CallActionExpression) ((View) getModel()).getElement();
		TreeIterator<EObject> it = cae.eAllContents();

		for (EObject eObj; it.hasNext();)
		{
			eObj = it.next();
			this.addListenerFilter(eObj.getClass().getName(), this, eObj);
		}
	}

	@Override
	protected void refreshVisuals()
	{
		super.refreshVisuals();
		updateFigure();
	}

	public void updateFigure()
	{
		CallActionExpression callActionExpression = (CallActionExpression) ((View) getModel()).getElement();

		if (callActionExpression != null)
		{
			String text;
			ComposedAdapterFactory factory = new ComposedAdapterFactory(EMFEditPlugin.getComposedAdapterFactoryDescriptorRegistry());
			text = ((IItemLabelProvider) factory.adapt(callActionExpression, IItemLabelProvider.class)).getText(callActionExpression);
			setLabelText("["+ text +"]");
			//setLabelText("[ " + callActionExpression.getCallActions().toString() + " ]");
		}
		else
		{
			setLabelText("");
		}
	}

	@Override
	protected void handleNotificationEvent(Notification event)
	{
		Object notifier = event.getNotifier();
		Object newValue = event.getNewValue();
		Object oldValue = event.getOldValue();
		int eventType = event.getEventType();

		if ((eventType == Notification.SET || eventType == Notification.ADD)
				&& (newValue instanceof CallAction || newValue instanceof MLExpression || newValue instanceof CallActionParameter))
		{
			this.addListenerFilter(newValue.getClass().getName(), this, (EObject) newValue);
			refreshVisuals();
		}
		else if (eventType == Notification.REMOVE
				&& (oldValue instanceof CallAction || oldValue instanceof MLExpression || oldValue instanceof CallActionParameter))
		{
			this.removeListenerFilter(oldValue.getClass().getName());
			refreshVisuals();
		}
		else if (notifier instanceof CallAction || notifier instanceof MLExpression || notifier instanceof CallActionParameter)
		{
			refreshVisuals();
		}

		super.handleNotificationEvent(event);
	}
}
