package de.mdelab.mlsdm.diagram.custom.edit.parts;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.EMFEditPlugin;
import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.swt.graphics.Color;

import de.mdelab.expressiondialogs.Utility;
import de.mdelab.mlcallactions.CallAction;
import de.mdelab.mlcallactions.CallActionExpression;
import de.mdelab.mlcallactions.CallActionParameter;
import de.mdelab.mlexpressions.MLExpression;
import de.mdelab.mlsdm.diagram.edit.parts.WrappingLabel5EditPart;
import de.mdelab.mlstorypatterns.BindingTypeEnum;
import de.mdelab.mlstorypatterns.StoryPatternElement;
import de.mdelab.mlstorypatterns.StoryPatternObject;
import de.mdelab.mlstorypatterns.diagram.custom.edit.parts.IMLExpressionEditPart;

public class CustomStoryPatternObjectClassifierLabelEditPart extends WrappingLabel5EditPart implements IMLExpressionEditPart {

	public CustomStoryPatternObjectClassifierLabelEditPart(View view)
	{
		super(view);
	}

	/*
	 * should be similar to addNotationalListeners of:
	 * 
	 * CustomActivityEdgeGuardConstraintLabelEditPart
	 * CustomActivityFinalNodeReturnValueLabelEditPart
	 * CustomAttributeAssignmentEditPart CustomCallActionExpressionEditPart
	 * CustomCallActionExpression2EditPart CustomCallActionExpression3EditPart
	 * CustomStoryPatternExpressionLinkFeatureNameLabelEditPart
	 * CustomStoryPatternObjectClassifierLabelEditPart
	 */
	@Override
	protected void addNotationalListeners()
	{
		super.addNotationalListeners();
		if (((View) getModel()).getElement() instanceof StoryPatternObject){
			MLExpression expr = ((StoryPatternObject) ((View) getModel()).getElement()).getAssignmentExpression();
	
			if (expr != null)
			{
				this.addListenerFilter(expr.eClass().getName(), this, expr);
	
				if (expr instanceof CallActionExpression)
				{
					TreeIterator<EObject> it = ((CallActionExpression) expr).eAllContents();
					for (EObject eObj; it.hasNext();)
					{
						eObj = it.next();
						this.addListenerFilter(Utility.getFilterId( eObj), this, eObj);
					}
				}
			}
		}
	}

	/*
	 * should be similar to handleNotificationEvent of:
	 * 
	 * CustomActivityEdgeGuardConstraintLabelEditPart
	 * CustomActivityFinalNodeReturnValueLabelEditPart
	 * CustomAttributeAssignmentEditPart CustomCallActionExpressionEditPart
	 * CustomCallActionExpression2EditPart CustomCallActionExpression3EditPart
	 * CustomStoryPatternExpressionLinkFeatureNameLabelEditPart
	 * CustomStoryPatternObjectClassifierLabelEditPart
	 */
	@Override
	protected void handleNotificationEvent(Notification event)
	{
		Object notifier = event.getNotifier();
		Object newValue = event.getNewValue();
		Object oldValue = event.getOldValue();
		int eventType = event.getEventType();

		if ((eventType == Notification.SET || eventType == Notification.ADD)
				&& (newValue instanceof CallAction || newValue instanceof MLExpression || newValue instanceof CallActionParameter))
		{
			this.addListenerFilter(newValue.getClass().getName(), this, (EObject) newValue);
			updateFigure();
		}
		else if (eventType == Notification.REMOVE
				&& (oldValue instanceof CallAction || oldValue instanceof MLExpression || oldValue instanceof CallActionParameter))
		{
			this.removeListenerFilter(oldValue.getClass().getName());
			updateFigure();
		}
		else if (notifier instanceof StoryPatternObject || notifier instanceof CallAction || notifier instanceof MLExpression
				|| notifier instanceof CallActionParameter)
		{
			updateFigure();
		}

		super.handleNotificationEvent(event);
	}

	protected void updateFigure()
	{
		Utility.adaptColor(getFigure(), ((StoryPatternElement) ((View) this.getModel()).getElement()).getModifier());

		StoryPatternObject spo = (StoryPatternObject) ((View) getModel()).getElement();

		String text = "";

		String eClassName = "[null]";
		if (spo.getType() != null)
		{
			eClassName = spo.getType().getName();
		}

		if (spo.getAssignmentExpression() != null)
		{
			ComposedAdapterFactory factory = new ComposedAdapterFactory(EMFEditPlugin.getComposedAdapterFactoryDescriptorRegistry());
			String text2 = ((IItemLabelProvider) factory.adapt(spo.getAssignmentExpression(), IItemLabelProvider.class)).getText(spo.getAssignmentExpression());

			text = ":= (" + eClassName + ") " + text2;

		}
		else
		{
			text = ":" + eClassName;

			if (spo.getBindingType() == BindingTypeEnum.BOUND)
			{
				setForegroundColor(new Color(null, 160, 160, 160));
				((WrappingLabel) this.getFigure()).setOpaque(false);
			}
			else if (spo.getBindingType() == BindingTypeEnum.CAN_BE_BOUND)
			{
				setBackgroundColor(new Color(null, 200, 200, 200));
				((WrappingLabel) this.getFigure()).setOpaque(true);
			}
			else if (spo.getBindingType() == BindingTypeEnum.UNBOUND)
			{
				((WrappingLabel) this.getFigure()).setOpaque(false);
				/*
				 * Leave the color as is, so it is green in case of created
				 * objects, red for destroyed objects, and black otherwise.
				 */
			}
		}

		if (text.length() > 50)
		{
			text = text.substring(0, 50);
			text += "...";
		}

		setLabelText(text);

		((WrappingLabel) getFigure()).setTextUnderline(true);
	}

	@Override
	protected void refreshVisuals()
	{
		super.refreshVisuals();
		updateFigure();
	}

	/* Temporary: until we have proper edit part, this represents story pattern object assignments
	 * (non-Javadoc)
	 * @see de.mdelab.mlstorypatterns.diagram.custom.edit.parts.IMLExpressionWrappingLabel#getWrappedExpression()
	 */
	@Override
	public MLExpression getMLExpression() {
		return ( (StoryPatternObject) ( (View) getModel() ).getElement() ).getAssignmentExpression();
	}
}
